Module: DevFlow

Defined in:
lib/dev_flow/task.rb,
lib/dev_flow.rb,
lib/dev_flow/app.rb,
lib/dev_flow/girc.rb,
lib/dev_flow/member.rb,
lib/dev_flow/roadmap.rb,
lib/dev_flow/version.rb,
lib/dev_flow/commands/ur.rb,
lib/dev_flow/task_console.rb,
lib/dev_flow/commands/info.rb,
lib/dev_flow/commands/init.rb,
lib/dev_flow/commands/close.rb,
lib/dev_flow/commands/cleanup.rb,
lib/dev_flow/commands/complete.rb,
lib/dev_flow/commands/progress.rb

Overview

representations for a task in roadmap and in Gantt chart.

@author: Huang Wei <[email protected]> version 1.0a

Defined Under Namespace

Classes: App, Cleanup, Close, Complete, Girc, Info, Init, Member, Progress, RoadMap, Task, Ur

Constant Summary collapse

VERSION =
'0.1.6'

Class Method Summary collapse

Class Method Details

.invoke!(config, command) ⇒ Object



21
22
23
24
25
26
# File 'lib/dev_flow.rb', line 21

def self.invoke! config, command
  # autoload command required files

  require "dev_flow/commands/#{command}"
  klass = command.to_s.capitalize
  eval(klass).new(config, command).process!
end